@@ -2,7 +2,7 @@ klcompreg.boot <- function(y, x, der, der2, id, b1, n, p, d, tol = 1e-07, maxite
   m <- Rfast::colmeans(y)
   e <- y - rep(m, rep(n, d) )
   for (i in 1:d) {
-    der[id[, i]] <- Rfast::colsums( e[, i] * x )
+    der[id[, i]] <- Rfast::eachcol.apply(x, e[, i] )
     for (j in i:d) {
       if (i != j) {
         der2[id[, i], id[, j]] <- der2[id[, j], id[, i]] <-  - crossprod(m[i] * m[j] * x, x)
@@ -20,7 +20,7 @@ klcompreg.boot <- function(y, x, der, der2, id, b1, n, p, d, tol = 1e-07, maxite
     m <- m1 / (Rfast::rowsums(m1) + 1)
     e <- y - m
     for (i in 1:d) {
-      der[id[, i]] <- Rfast::colsums( e[, i] * x )
+      der[id[, i]] <- Rfast::eachcol.apply(x, e[, i] )
       for (j in i:d) {
         if (i != j) {
           der2[id[, i], id[, j]] <- der2[id[, j], id[, i]] <-   - crossprod(m[, i] * m[, j] * x, x)
