@@ -15,7 +15,7 @@ rda.tune <- function(x, ina, nfolds = 10, gam = seq(0, 1, by = 0.1), del = seq(0
   D <- dim(x)[2]  ## number of variables
   sk <- array( dim = c(D, D, nc) )
   lg <- length(gam)    ;    ld <- length(del)
-  if ( is.null(folds) )  folds <- Compositional::makefolds(ina, nfolds = nfolds,
+  if ( is.null(folds) )  folds <- .makefolds(ina, nfolds = nfolds,
                                                            stratified = stratified, seed = seed)
   nfolds <- length(folds)
 
@@ -24,9 +24,9 @@ rda.tune <- function(x, ina, nfolds = 10, gam = seq(0, 1, by = 0.1), del = seq(0
     group <- matrix(nrow = length(gam), ncol = length(del) )
     cl <- parallel::makePSOCKcluster(ncores)
     doParallel::registerDoParallel(cl)
-    if ( is.null(folds) )  folds <- Compositional::makefolds(ina, nfolds = nfolds,
+    if ( is.null(folds) )  folds <- .makefolds(ina, nfolds = nfolds,
                                                              stratified = stratified, seed = seed)
-    ww <- foreach(vim = 1:nfolds, .combine = cbind, .export = c("mahala", "rowMaxs", "colGroup", "cova"), 
+    ww <- foreach::foreach(vim = 1:nfolds, .combine = cbind, .export = c("mahala", "rowMaxs", "colGroup", "cova"),
 	      .packages = c("Rfast", "Rfast2") ) %dopar% {
       test <- x[ folds[[ vim ]], , drop = FALSE]  ## test sample
       id <- ina[ folds[[ vim ]] ] ## groups of test sample
@@ -57,7 +57,7 @@ rda.tune <- function(x, ina, nfolds = 10, gam = seq(0, 1, by = 0.1), del = seq(0
       }
       return( as.vector( group ) )
     }
-    stopCluster(cl)
+    parallel::stopCluster(cl)
 
     per <- array( dim = c( lg, ld, nfolds ) )
     for ( i in 1:nfolds )  per[, , i] <- matrix( ww[, i], nrow = lg )
@@ -96,7 +96,7 @@ rda.tune <- function(x, ina, nfolds = 10, gam = seq(0, 1, by = 0.1), del = seq(0
           per[k1, k2, vim] <- mean( g == id )
         }
       }
-	  
+
     }  ##  end  for (vim in 1:nfolds) {
     runtime <- proc.time() - runtime
   }
@@ -109,3 +109,47 @@ rda.tune <- function(x, ina, nfolds = 10, gam = seq(0, 1, by = 0.1), del = seq(0
   colnames(result) <- c('optimal', 'best gamma', 'best delta')
   list(per = per, percent = percent, se = su, result = result, runtime = runtime)
 }
+
+
+
+
+
+.makefolds <- function(ina, nfolds = 10, stratified = TRUE, seed = NULL) {
+  names <- paste("Fold", 1:nfolds)
+  runs <- sapply(names, function(x) NULL)
+  if ( !is.null(seed) )  set.seed(seed)
+
+  if ( !stratified ) {
+    rat <- length(ina) %% nfolds
+    suppressWarnings({
+      mat <- matrix( Rfast2::Sample.int( length(ina) ), ncol = nfolds )
+    })
+    mat[-c( 1:length(ina) )] <- NA
+    for ( i in 1:c(nfolds - 1) )  runs[[ i ]] <- mat[, i]
+    a <- prod(dim(mat)) - length(ina)
+    runs[[ nfolds ]] <- mat[1:c(nrow(mat) - a), nfolds]
+  } else {
+    labs <- unique(ina)
+    run <- list()
+    for (i in 1:length(labs)) {
+      names <- which( ina == labs[i] )
+      run[[ i ]] <- sample(names)
+    }
+    run <- unlist(run)
+    for ( i in 1:length(ina) ) {
+      k <- i %% nfolds
+      if ( k == 0 )  k <- nfolds
+      runs[[ k ]] <- c( runs[[ k ]], run[i] )
+    }
+  }
+
+  for (i in 1:nfolds)  {
+    if ( any( is.na(runs[[ i ]]) ) )  runs[[ i ]] <- runs[[ i ]][ !is.na(runs[[ i ]]) ]
+  }
+
+  if ( length(runs[[ nfolds ]]) == 0 ) runs[[ nfolds ]] <- NULL
+  runs
+}
+
+
+
