@@ -1,4 +1,4 @@
-tflr.betest <- function(y, x, B, R = 999, ncores = 1) {
+tflr.betest <- function(y, x, B, tol = 1e-6, R = 999, ncores = 1) {
 
   yhat <- x %*% B
   kl <- y * log(y / yhat)
@@ -10,7 +10,7 @@ tflr.betest <- function(y, x, B, R = 999, ncores = 1) {
   if ( ncores <= 1 ) {
     for ( i in 1:R ) {
       id <- Rfast2::Sample.int(n, n)
-      pkl[i] <- Compositional::tflr(y, x[id, ])$kl
+      pkl[i] <- Compositional::tflr(y, x[id, ], tol = tol)$kl
     }
 
   } else {
@@ -20,7 +20,7 @@ tflr.betest <- function(y, x, B, R = 999, ncores = 1) {
     pkl <- foreach::foreach(i = 1:R, .combine = "c",
                            .packages = c("Compositional", "Rfast", "Rfast2") ) %dopar% {
       id <- Rfast2::Sample.int(n, n)
-      return( Compositional::tflr(y, x[id, ])$kl )
+      return( Compositional::tflr(y, x[id, ], tol = tol)$kl )
     }
   }
 
